{% load i18n %}
<!DOCTYPE html>
<html>
<head>
    <title>{% trans 'app_name' %}</title>
    <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
    <META name="description" content="OppiaMobile learning"/> 
	<META name="keywords" content="oppia, oppiamobile,quiz,assessment,mobile,android,learning, video, media"/> 
    <link href="{{ STATIC_URL }}oppia/style.css" rel="stylesheet" type="text/css"/>
    <link rel="shortcut icon" href="{{ STATIC_URL }}oppia/images/favicon.ico"/>	
    {% block extra_styles %}
    {% endblock extra_styles %}
        
    {% block extra_scripts %}
    {% endblock extra_scripts %}
</head>

<body {% block extra_body %}{% endblock extra_body %}>
{% include "includes/header.html" %}

<div id="main">
<div class="content">
{% block content %}
{% endblock content %}
</div>
</div>

{% include "includes/footer.html" %}

<script type="text/javascript">

  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', 'UA-3609005-9']);
  _gaq.push(['_setDomainName', 'mquiz.org']);
  _gaq.push(['_trackPageview']);

  (function() {
    var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
    ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();

</script>
</body>
</html>

