{% load i18n %}
<div class="page_navigator">
	{% if page.has_previous %}
        <a href="?page={{ page.previous_page_number }}">&lt;&lt; {% trans 'previous' %}</a>
    {% endif %}

    <span class="current">
        {% blocktrans with i=page.number x=page.paginator.num_pages %}Page {{ i }} of {{ x }}{% endblocktrans %}
    </span>

    {% if page.has_next %}
        <a href="?page={{ page.next_page_number }}">{% trans 'next' %} &gt;&gt;</a>
    {% endif %}
</div>