{% extends "base.html" %}
{% load i18n %}
{% load title_lang %}

{% block content %}

<h2><a href="{% url 'oppia_recent_activity' course.id %}">{{ course.title|title_lang:LANGUAGE_CODE }}</a> > {% trans 'schedules' %}</h2>

{% if schedules %}
	<ul>
	{% for schedule in schedules %}
		<li>
			<a href="{% url 'oppia.views.schedule_edit' schedule.course.id schedule.id %}">{{ schedule.title }}</a> 
			{% if schedule.default %}	
				({% trans 'default' %})
			{% endif %} 
			
		</li> 
	{% endfor %}
	</ul>
{% else %}
	<p>{% trans 'No schedules' %}</p>
	
{% endif %}

<p><a href="{% url 'oppia_schedule_add' course.id %}">{% trans 'Add a schedule' %}</a></p>

{% endblock %}