@CHARSET "UTF-8";

* {padding:0; margin:0;}

body {
	margin:0 0 5px 0;
	background:#fff;
	color:#444;
	font-size: 120%; 
	font-family: Helvetica,Arial,sans-serif;
    background:#eee;
}

#header {
	background: none repeat scroll 0 0 #77A240;
	color: #fff;
  	padding:5px 5px;
	text-align: center;
}

#header a {
    color: #fff;
    text-decoration:underline;
}

#header-title {
	float:left;	
}

#header-title h1 {
	font-size:130%;
	display:inline;
	vertical-align:middle;
}

#header-logo {
	float:left;
}

#header-right {
	float:right;	
	text-align:right;
}


#footer {
	text-align:center;
	margin-top:10px;
	font-size:80%;
}

.clickable {
	cursor:pointer;
}

span.points, span.badges {
	border: 0px solid #aaa;
	padding: 3px;
	border-radius: 0.3em;
	-moz-border-radius: 0.3em;
	-webkit-border-radius: 0.3em;
	font-family: courier;
	font-weight:normal;
	color: #fff;
	background:#495525;
	white-space: nowrap;
	text-align:right;
	display:inline;
	margin:5px;
}

span.badges img {
	position: relative;
	top:5px;
	margin:2px;	
}