{% extends "base.html" %}
{% load i18n %}
{% load display_functions %}
{% block content %}
<h2>{% trans 'page_title_leaderboard' %}</h2>

{% if page.object_list.count > 0  %}
	{% include "oppia/includes/page_navigator.html" %}
       
	{% for user in page.object_list %}
		{% if user.total %}
	       	<div class="leaderboard">
	       		<div class="lbrank">{{ forloop.counter0|get_index:page.start_index }}</div>
	       		<div class="lbpoints"><span class="points" title="{{ user.total  }} {% trans 'points' %}">{{ user.total }}</span>
	       		<span class="badges" title="{{ user.badges }} {% trans 'badges' %}"><img src="{{ STATIC_URL }}oppia/images/badge.png" alt="{{ user.badges }} {% trans 'badges' %}"/>{{ user.badges }}</span></div>  
	       		<div class="lbname">{{ user.first_name }} {{ user.last_name }}</div>
	       		<div style="clear:both"></div>  	
	       	</div>
	    {% endif %}
    {% endfor %}
	    
	{% include "oppia/includes/page_navigator.html" %}
{% endif %}

{% endblock %}